@@ -4,11 +4,13 @@ from eth_enr.abc import (  # noqa: F401
     ENRManagerAPI,
     IdentitySchemeAPI,
     IdentitySchemeRegistryAPI,
+    QueryableENRDatabaseAPI,
     UnsignedENRAPI,
 )
 from eth_enr.enr import ENR, UnsignedENR  # noqa: F401
 from eth_enr.enr_db import ENRDB  # noqa: F401
 from eth_enr.enr_manager import ENRManager  # noqa: F401
+from eth_enr.exceptions import OldSequenceNumber, UnknownIdentityScheme  # noqa: F401
 from eth_enr.identity_schemes import (  # noqa: F401
     IdentitySchemeRegistry,
     V4CompatIdentityScheme,
@@ -16,3 +18,4 @@ from eth_enr.identity_schemes import (  # noqa: F401
     default_identity_scheme_registry,
     discv4_identity_scheme_registry,
 )
+from eth_enr.query_db import QueryableENRDB  # noqa: F401
