@@ -1,9 +1,18 @@
 IDENTITY_SCHEME_ENR_KEY = b"id"
 ENR_REPR_PREFIX = "enr:"  # prefix used when printing an ENR
 MAX_ENR_SIZE = 300  # maximum allowed size of an ENR
+
+V4 = b"v4"
+V4_SIGNATURE_KEY = b"secp256k1"
+
 IP_V4_ADDRESS_ENR_KEY = b"ip"
+IP_V6_ADDRESS_ENR_KEY = b"ip6"
 UDP_PORT_ENR_KEY = b"udp"
 TCP_PORT_ENR_KEY = b"tcp"
 
+IP_V6_ADDRESS_ENR_KEY = b"ip6"
+UDP6_PORT_ENR_KEY = b"udp6"
+TCP6_PORT_ENR_KEY = b"tcp6"
+
 IP_V4_SIZE = 4  # size of an IPv4 address
 IP_V6_SIZE = 16  # size of an IPv6 address
